summaryrefslogtreecommitdiffstats
path: root/Http/Authentication/AuthenticationSuccessHandlerInterface.php
diff options
context:
space:
mode:
Diffstat (limited to 'Http/Authentication/AuthenticationSuccessHandlerInterface.php')
-rw-r--r--Http/Authentication/AuthenticationSuccessHandlerInterface.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/Http/Authentication/AuthenticationSuccessHandlerInterface.php b/Http/Authentication/AuthenticationSuccessHandlerInterface.php
index 235eb94..30b5e26 100644
--- a/Http/Authentication/AuthenticationSuccessHandlerInterface.php
+++ b/Http/Authentication/AuthenticationSuccessHandlerInterface.php
@@ -2,7 +2,7 @@
namespace Symfony\Component\Security\Http\Authentication;
-use Symfony\Component\EventDispatcher\EventInterface;
+use Symfony\Component\HttpKernel\Event\GetResponseEventArgs;
use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
use Symfony\Component\HttpFoundation\Request;
@@ -22,12 +22,12 @@ interface AuthenticationSuccessHandlerInterface
* is called by authentication listeners inheriting from
* AbstractAuthenticationListener.
*
* @param EventInterface $event the "core.security" event, this event always
* has the kernel as target
* @param Request $request
* @param TokenInterface $token
*
* @return Response the response to return
*/
- function onAuthenticationSuccess(EventInterface $event, Request $request, TokenInterface $token);
+ function onAuthenticationSuccess(GetResponseEventArgs $eventArgs, Request $request, TokenInterface $token);
} \ No newline at end of file
@@ -22,12 +22,12 @@ interface AuthenticationSuccessHandlerInterface
* AbstractAuthenticationListener.
*
- * @param EventInterface $event the "core.security" event, this event always
+ * @param GetResponseEventArgs $eventArgs the "onCoreSecurity" event, this event always
* has the kernel as target
* @param Request $request